function [kx]=CorrVectorData(model,x)
//Calculates correlation between data point x and other data points, that were used for learning of kriging model.
//  
// Calling Sequence
//            kx=CorrVectorData(model,x)
//
//Parameters
//            x: data point, matrix (t*n ), t -data points, n - number of dimensions.
//            model: kriging model. 
// Output
//            kx: column vector (m*t).
//Description
//Calculates correlation between data point x and other data points, that were used for learning of kriging model.
//Uses model.cov - correlation function; model.theta - correlation hyper-parameters.
// Note:
//          This function uses global variable S_kriging. 
//Examples
// See demos directory for more examples.
//See also
//           km
//           findTheta
//           SimulateGaussian
//           SimCondGaussian
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//
//

global S_kriging;  
[t,n]=size(x);
kx=zeros(model.m,t);


					if model.cov == 'gaussian' then funct=gaussian;
					elseif model.cov == 'matern_5_2' then funct=matern_5_2;
					elseif model.cov == 'exponential_1' then funct=exponential_1;
					elseif model.cov == 'exponential_1_9' then funct=exponential_1_9;
					end;

					for j=1:t 
										for i=1:model.m
																		kx(i,j)=funct(S_kriging(i,:)-x(j,:),model.theta);
										end;
					end;


endfunction


