function  [v, dv] = matern_5_2(d,theta)
// Matern v=5_2 correlation function.
//  
// Calling Sequence
//            [v] =  matern5_2(d,theta)
//            [v, dv] =  matern5_2(d,theta)
//
// Parameters
//            d:  disstance between points (m*n) matrix. m - number of distances, n - number of dimensions.
//            theta: lenght scale hyperparameter (1*n) row vector or scalar (to use the same scale for all dimensions).
//
// Output
//            v: correlation (m*1) column vector.
//            dv: derrivative (not implemented).
//
//Description
//Gaussian correlation function.          
//Examples
//v=matern5_2(3,1); 
//See also
//           km
//           findTheta
//           simGaussian
//           gaussian
//          
//Authors
//          Janis Janusevskis, 3MI/EMSE
//Bibliography 
//

[m n] = size(d);  // number of distances and dimension of data
[mt nt]=size(theta);
if  mt == 1 & nt==1 then
  theta = ones(1,n) .*. theta;
elseif  nt ~= n | mt ~= 1 then
  error(sprintf('Length of theta must be 1*1  or 1*%d',n))
end
theta=ones(m,1)*theta;
d=abs(d);
v=prod((1+sqrt(5)*d./theta+5*d.*d./(3*theta.*theta)).*exp(-sqrt(5)*d./theta),'c');

dv=%nan;
endfunction

